==> haskell-string-conversions-0.4.0.1-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-3MMXD5M4rSiEMbkzmgAltv
key:                  string-conversions-0.4.0.1-3MMXD5M4rSiEMbkzmgAltv
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  f60aa3cb6520792e60666931eddf467e
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-3MMXD5M4rSiEMbkzmgAltv
depends:
    base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
    utf8-string-1.0.2-7vJf5AoNOLyFfjCFEBOlRd

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-conversions-0.4.0.1-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-oe98zMbW0GDu9Nzl4JFng
key:                  string-conversions-0.4.0.1-oe98zMbW0GDu9Nzl4JFng
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  68fdd3f9ad56ab84d88ec30fc5d76801
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-oe98zMbW0GDu9Nzl4JFng
depends:
    base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
    utf8-string-1.0.2-5jfGmdF6tr2LafWWNuWYmN

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
